import typing

from starlette.responses import Response

try:
	from ujson import dumps
except ImportError:
	dumps = None
	
valid_args = {
	'encode_html_chars', # Used to enable special encoding of "unsafe" HTML characters into safer Unicode sequences. Default is False
	'ensure_ascii', # Limits output to ASCII and escapes all extended characters above 127. Default is true. If your end format supports UTF-8 setting this option to false is highly recommended to save space
	'escape_forward_slashes', # Controls whether forward slashes (/) are escaped. Default is True
	'indent' # Controls whether indention ("pretty output") is enabled. Default is 0 (disabled)
}

class UJsonResponse(Response):
	'''
	See available render kwargs here
		https://github.com/esnme/ultrajson/blob/master/README.rst
	'''
	media_type = "application/json"
	
	def __init__(self, *args, **kwargs):
		self.render_args = {arg: v for arg,v in kwargs.items() if arg in valid_args}
		if 'ensure_ascii' not in self.render_args:
			self.render_args['ensure_ascii'] = False
		super(UJsonResponse, self).__init__(*args, **kwargs)
		
	def render(self, content: typing.Any) -> bytes:
		return dumps(content, **self.render_args).encode("utf-8")


import typing

from starlette.responses import Response

try:
	from orjson import dumps
except ImportError:
	dumps = None
	
valid_args = {
	'default', # To serialize a subclass or arbitrary types, specify default as a callable that returns a supported type. default may be a function, lambda, or callable class instance.
	'option', # To specify multiple options, mask them together, e.g., option=orjson.OPT_STRICT_INTEGER | orjson.OPT_NAIVE_UTC
}
	
class ORJsonResponse(Response):
	'''
	See available dump kwargs here
		https://github.com/ijl/orjson#serialize
	'''
	media_type = "application/json"
	
	def __init__(self, *args, **kwargs):
		self.render_args = {arg: v for arg,v in kwargs.items() if arg in valid_args}
		super(ORJsonResponse, self).__init__(*args, **kwargs)
		
	def render(self, content: typing.Any,) -> bytes:
		return dumps(content, **self.render_args)


import typing

from starlette.responses import Response

try:
	from rapidjson import dumps
except ImportError:
	dumps = None
	
valid_args = {
	'skipkeys', # (bool) – whether invalid dict keys will be skipped
	'ensure_ascii', # (bool) – whether the output should contain only ASCII characters
	'indent', # (int) – indentation width to produce pretty printed JSON
	'default', # (callable) – a function that gets called for objects that can’t otherwise be serialized
	'sort_keys', # (bool) – whether dictionary keys should be sorted alphabetically
	'number_mode', # (int) – enable particular behaviors in handling numbers
	'datetime_mode', # (int) – how should datetime, time and date instances be handled
	'uuid_mode', # (int) – how should UUID instances be handled
	'allow_nan' # (bool) – compatibility flag equivalent to number_mode=NM_NAN
}
	
class RapidJsonResponse(Response):
	'''
	See available dump kwargs here
		https://python-rapidjson.readthedocs.io/en/latest/dumps.html
	'''
	media_type = "application/json"
	
	def __init__(self, *args, **kwargs):
		self.render_args = {arg: v for arg,v in kwargs.items() if arg in valid_args}
		super(RapidJsonResponse, self).__init__(*args, **kwargs)
		
	def render(self, content: typing.Any) -> bytes:
		return dumps(content, **self.render_args).encode("utf-8")


import os

from setuptools import setup

NAME = 'starlette_json'
VERSION = '19.10.24'
DESCRIPTION = 'Custom json serializers for the Starlette web framework.'
URL = 'https://github.com/chrisliveseer/starlette-json'
EMAIL = 'chris@liveseer.com'
AUTHOR = 'Chris Liveseer'
REQUIRES_PYTHON = '>=3.6.0'

here = os.path.abspath(os.path.dirname(__file__))

try:
	with open(os.path.join(here, 'README.md'), encoding='utf-8') as inf:
		long_description = inf.read()
except FileNotFoundError:
	long_description = DESCRIPTION

setup(
	name=NAME,
	version=VERSION,
	author=AUTHOR,
	author_email=EMAIL,
	description=DESCRIPTION,
	long_description=long_description,
	long_description_content_type='text/markdown',
	license='BSD',
	keywords='starlette json ujson orjson rapidjson',
	url=URL,
	packages=['starlette_json'],
	platforms=['any'],
	classifiers=[
		'License :: OSI Approved :: BSD License',
		'Programming Language :: Python',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.6',
		'Programming Language :: Python :: 3.7',
		'Programming Language :: Python :: 3.8',
		'Programming Language :: Python :: Implementation :: CPython',
	],
	python_requires=REQUIRES_PYTHON,
	install_requires=['starlette'],
	extra_requires=[
		'orjson',
		'ujson',
		'python-rapidjson'
	],
	include_package_data=True,
)